#
##
### CODE FOR ONLINE APPENDIX/SUPPLEMENTAL INFORMATION:
##
library(foreign)
library(readstata13)
options(digits=2,scipen=120)
setwd("~/Dropbox/Judicial Independence Since Conflict")
#write.csv(data2,file="~/Desktop/epperly_sievert_data.csv")
data2 <- read.csv("~/Dropbox/Judicial Independence Since Conflict/PRQ replication files/Epperly and Sievert PRQ data.csv")

#xtreg difflji3yrs CWonset3years coup3yrs todemocracy3yrs tocivilian3yrs
#tomonarchy3yrs tomilitary3yrs, vce(robust)

library(memisc)
library(foreign)
library(readstata13)
library(simcf)
library(lme4)
library(ggplot2)
library(MASS)
library(reshape2)
library(extrafont)
library(sandwich)
library(lmtest)
library(pscl)
library(texreg)
library(spduration)

data2$conflictyears <- as.numeric(data2$conflictyears)
data2$transition <- 0
data2$transition[data2$tomilitary3yrs==1] <- 1
data2$transition[data2$tocivilian3yrs==1] <- 1
data2$transition[data2$tomonarchy3yrs==1] <- 1

form.df <- difflji3yrs ~ CWonset3years + tomilitary3yrs + 
		tocivilian3yrs + tomonarchy3yrs + conflictyears + transition +
		coup3yrs + cname + year + difflji3yrs + democracylag3 + democracy
form.dj <- djji_diff ~ djdj_changeany2 + djji_diff_trichotomous + 
		CWonset3years + tomilitary3yrs + 
		tocivilian3yrs + tomonarchy3yrs + conflictyears + transition +
		coup3yrs + cname + year  + democracylag3 + democracy

df.data <- extractdata(form.df,data2,na.rm=TRUE)
dj.data <- extractdata(form.dj,data2,na.rm=TRUE)
dim(df.data)
dim(dj.data)
df.democ.data2 <- subset(df.data,democracylag3==1) # Robustness, includes those countries that cease to become democracies
df.democ.data  <- subset(df.democ.data2,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum
dj.democ.data2 <- subset(dj.data,democracylag3==1) # Robustness, includes those countries that cease to become democracies 
dj.democ.data <- subset(dj.democ.data2,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum 

sd(abs(df.democ.data$difflji3yrs),na.rm=TRUE)
df.democ.data$change3 <- NA
df.democ.data$change3[abs(df.democ.data$difflji3yrs) > sd(abs(df.democ.data$difflji3yrs),na.rm=TRUE)] <- 1
df.democ.data$change3[abs(df.democ.data$difflji3yrs) <= sd(abs(df.democ.data$difflji3yrs),na.rm=TRUE)] <- 0
summary(as.factor(df.democ.data$change3))
#print(cbind(abs(df.democ.data$difflji3yrs),df.democ.data$change3))
df.democ.data$sigchange <- df.democ.data$change3
# This gives us those observations among these data that have a >1 standard deviation
# change in the 3-year difference in LJI




#
# Descriptive statistics
#
#Table 1
summary(as.factor(dj.democ.data$djji_diff))
summary(as.factor(abs(dj.democ.data$djji_diff)))
summary(as.factor(dj.democ.data$djdj_changeany2))

#Table 2
summary(df.democ.data$difflji3yrs)
summary(abs(df.democ.data$difflji3yrs))

#Table 3
summary(as.factor(df.democ.data$sigchange))

#Table 4
summary(as.factor(dj.democ.data$CWonset3years))
summary(as.factor(dj.democ.data$transition))
summary(as.factor(dj.democ.data$coup3yrs))

#Table 5
summary(as.factor(df.democ.data$CWonset3years))
summary(as.factor(df.democ.data$transition))
summary(as.factor(df.democ.data$coup3yrs))

#Appendix Figure 1 code:
#
form.df <- difflji3yrs ~ CWonset3years + tomilitary3yrs + 
		tocivilian3yrs + tomonarchy3yrs + conflictyears + transition +
		coup3yrs + cname + year + difflji3yrs + democracylag3 + democracy + lji
df.data <- extractdata(form.df,data2,na.rm=TRUE)
dim(df.data)
df.democ.data2 <- subset(df.data,democracylag3==1) # Robustness, includes those countries that cease to become democracies
df.democ.data  <- subset(df.democ.data2,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum

plot <- ggplot(df.democ.data,aes(x=lji)) + stat_density(geom="line",size=1)
plot <- plot + scale_x_continuous(name='Latent judicial independence',limits=c(0,1))
plot <- plot + scale_y_continuous('Density')
plot <- plot + theme(title="")
plot <- plot + theme_bw()
plot <- plot + theme(plot.title=element_text(size=25))
plot <- plot + theme(axis.title.y = element_text(size=16,angle=90),
          axis.text.y=element_text(size=16))
plot <- plot + theme(axis.title.x = element_text(size=16,vjust=0),
          axis.text.x  = element_text(size=16))
plot
#ggsave(plot,filename="distribution_of_lji.pdf",width=6,height=6)	

#Appendix Figure 2 code:
#
dat_noonset <- as.data.frame(df.democ.data$difflji3yrs[df.democ.data$CWonset3years==0])
names(dat_noonset)[1] <- "diffjii"
dat_onset <- as.data.frame(df.democ.data$difflji3yrs[df.democ.data$CWonset3years==1])
names(dat_onset)[1] <- "diffjii"
# Figure 2 plot (a)
plot <- ggplot(dat_noonset,aes(x= diffjii)) + 
	stat_density(geom="line",size=1,color="gray")
plot <- plot + scale_x_continuous(name='')
plot <- plot + scale_y_continuous('Density')
plot <- plot + stat_density(data=dat_onset,geom="line",size=1.2,linetype="dashed")
plot <- plot + theme(title="")
plot <- plot + theme_bw()
plot <- plot + theme(plot.title=element_text(size=25))
plot <- plot + theme(axis.title.y = element_text(size=16,angle=90),
          axis.text.y=element_text(size=16))
plot <- plot + theme(axis.title.x = element_text(size=16,vjust=0),
          axis.text.x  = element_text(size=16))
plot
#ggsave(plot,filename="distribution_of_lji_by_onset.pdf",width=6,height=6)	

# Figure 2 plot (b)
dat_noonsetABS <- as.data.frame(abs(df.democ.data$difflji3yrs[df.democ.data$CWonset3years==0]))
names(dat_noonsetABS)[1] <- "diffjii"
dat_onsetABS <- as.data.frame(abs(df.democ.data$difflji3yrs[df.democ.data$CWonset3years==1]))
names(dat_onsetABS)[1] <- "diffjii"

plot <- ggplot(dat_noonsetABS,aes(x= diffjii)) + 
	stat_density(geom="line",size=1,color="gray")
plot <- plot + scale_x_continuous(name='')
plot <- plot + scale_y_continuous('Density')
plot <- plot + stat_density(data=dat_onsetABS,geom="line",size=1.2,linetype="dashed")
plot <- plot + theme(title="")
plot <- plot + theme_bw()
plot <- plot + theme(plot.title=element_text(size=25))
plot <- plot + theme(axis.title.y = element_text(size=16,angle=90),
          axis.text.y=element_text(size=16))
plot <- plot + theme(axis.title.x = element_text(size=16,vjust=0),
          axis.text.x  = element_text(size=16))
plot
#ggsave(plot,filename="distribution_of_absolute_lji_by_onset.pdf",width=6,height=6)	


##
## CONFLICT YEARS
##
dj.democ.data$conflictyears <- as.numeric(as.character(dj.democ.data$conflictyears))
# Standardize the coefficient for conflict years:
dj.democ.data$conflictyears.std <- (dj.democ.data$conflictyears - 
	mean(dj.democ.data$conflictyears,na.rm=TRUE))/
	(2*sd(dj.democ.data$conflictyears,na.rm=TRUE))
df.democ.data$conflictyears.std <- (df.democ.data$conflictyears - 
	mean(df.democ.data$conflictyears,na.rm=TRUE))/
	(2*sd(df.democ.data$conflictyears,na.rm=TRUE))

dj.years1 <- glm(djji_diff ~ CWonset3years + conflictyears.std + 
		transition + coup3yrs, data=dj.democ.data,family="gaussian")
dj.years1.abs <- glm(abs(djji_diff) ~ CWonset3years + conflictyears.std + 
		transition + coup3yrs, data=dj.democ.data,family="gaussian")
dj.years2 <- (glm(djdj_changeany2 ~ CWonset3years +  conflictyears.std + transition +	
		coup3yrs,family=binomial(link="logit"),
		data= dj.democ.data))				
df.years1 <- glm(difflji3yrs ~ CWonset3years + conflictyears.std + 
		transition + coup3yrs,data= df.democ.data,family="gaussian")
df.years1.abs <- glm(abs(difflji3yrs) ~ CWonset3years + conflictyears.std + 
		transition + coup3yrs, data=df.democ.data,family="gaussian")
df.years2 <- (glm(sigchange ~ CWonset3years + conflictyears.std + transition +	
		coup3yrs,family=binomial(link="logit"),
		data= df.democ.data))
#
# Code for appendix Table 6 below:
#
screenreg(list(coeftest(dj.years1, vcov = vcovHC(dj.years1, "HC1")),
	coeftest(dj.years1.abs, vcov = vcovHC(dj.years1.abs, "HC1")),
	coeftest(dj.years2, vcov = vcovHC(dj.years2, "HC1")),
	coeftest(df.years1, vcov = vcovHC(df.years1, "HC1")),
	coeftest(df.years1.abs, vcov = vcovHC(df.years1.abs, "HC1")),
	coeftest(df.years2, vcov = vcovHC(df.years2, "HC1"))
	),
	stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE,
	custom.coef.names=c(
	"(Intercept)",
	"Conflict onset",
	"Conflict years",
	"Autocratic interregnum",
	"Coup"
	),
	caption.above=TRUE,label="table:models3",
	custom.model.names=c("Model $1_y$","Model $2_y$", "Model $5_y$","Model $3_y$","Model $4_y$", "Model $6_y$")
	)
# gotta put in AIC/no. obs in by hand
options(digits=7)
AIC(dj.years1)
AIC(dj.years1.abs)
AIC(dj.years2)
AIC(df.years1)
AIC(df.years1.abs)
AIC(df.years2)
options(digits=2)


#
# Logged conflict years
#
dj.democ.data$conflictyears1 <- dj.democ.data$conflictyears
dj.democ.data$conflictyears1[dj.democ.data$conflictyears1==0] <- 1
df.democ.data$conflictyears1 <- df.democ.data$conflictyears
df.democ.data$conflictyears1[df.democ.data$conflictyears1==0] <- 1

dj.lyears1 <- lm(djji_diff ~ CWonset3years + log(conflictyears1) + 
		transition + coup3yrs, data=dj.democ.data)
dj.lyears1.abs <- lm(abs(djji_diff) ~ CWonset3years + log(conflictyears1) + 
		transition + coup3yrs, data=dj.democ.data)
dj.lyears2 <- (glm(djdj_changeany2 ~ CWonset3years +  log(conflictyears1) + transition +	
		coup3yrs,family=binomial(link="logit"),
		data= dj.democ.data))				
df.lyears1 <- lm(difflji3yrs ~ CWonset3years + log(conflictyears1) + 
		transition + coup3yrs,data= df.democ.data)
df.lyears1.abs <- lm(abs(difflji3yrs) ~ CWonset3years + log(conflictyears1) + 
		transition + coup3yrs, data=df.democ.data)
df.lyears2 <- (glm(sigchange ~ CWonset3years + log(conflictyears1) + transition +	
		coup3yrs,family=binomial(link="logit"),
		data= df.democ.data))
#
# Code for appendix Table 7 below:
#
screenreg(list(
	coeftest(dj.lyears1, vcov = vcovHC(dj.lyears1, "HC1")),
	coeftest(dj.lyears1.abs, vcov = vcovHC(dj.lyears1.abs, "HC1")),
	coeftest(dj.lyears2, vcov = vcovHC(dj.lyears2, "HC1")),
	coeftest(df.lyears1, vcov = vcovHC(df.lyears1, "HC1")),
	coeftest(df.lyears1.abs, vcov = vcovHC(df.lyears1.abs, "HC1")),
	coeftest(df.lyears2, vcov = vcovHC(df.lyears2, "HC1"))
	), 
	stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE,
	custom.coef.names=c(
	"(Intercept)",
	"Conflict onset",
	"log(conflict years)",
	"Autocratic interregnum",
	"Coup"
	),
	caption.above=TRUE,label="table:loggedconflict",sideways=TRUE,
	custom.model.names=c("Model $1_y$","Model $2_y$", "Model $5_y$","Model $3_y$","Model $4_y$", "Model $6_y$")
	)
options(digits=7)
AIC(dj.lyears1)
AIC(dj.lyears1.abs)
AIC(df.lyears1)
AIC(df.lyears2)
options(digits=2)


#
# Appendix Table 8, including transitions, below:
#
#
# Including observations where democracy failed in the interim (transition not interregnum)
#	
sd(abs(df.democ.data2$difflji3yrs),na.rm=TRUE)
df.democ.data2$change3 <- NA
df.democ.data2$change3[abs(df.democ.data2$difflji3yrs) > sd(abs(df.democ.data2$difflji3yrs),na.rm=TRUE)] <- 1
df.democ.data2$change3[abs(df.democ.data2$difflji3yrs) <= sd(abs(df.democ.data2$difflji3yrs),na.rm=TRUE)] <- 0
summary(as.factor(df.democ.data2$change3))
print(cbind(abs(df.democ.data2$difflji3yrs),df.democ.data2$change3))
df.democ.data2$sigchange <- df.democ.data2$change3

dj1T <- (lm(djji_diff ~ CWonset3years + transition +	
		coup3yrs,
		data= dj.democ.data2))
dj1.absT <- (lm(abs(djji_diff) ~ CWonset3years + transition +	
		coup3yrs,
		data= dj.democ.data2))
df1T <- (lm(difflji3yrs ~ CWonset3years + transition +	
		coup3yrs,
		data= df.democ.data2))				
df1.absT <- (lm(abs(difflji3yrs) ~ CWonset3years + transition +	
		coup3yrs,
		data= df.democ.data2))	
		
screenreg(list(
	coeftest(dj1T, vcov = vcovHC(dj1T, "HC1")),
	coeftest(dj1.absT, vcov = vcovHC(dj1.absT, "HC1")),
	coeftest(df1T, vcov = vcovHC(df1T, "HC1")),
	coeftest(df1.absT, vcov = vcovHC(df1.absT, "HC1"))
	), 
	stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE,
	custom.coef.names=c(
	"(Intercept)",
	"Conflict onset",
	"Autocratic transition",
	"Coup"
	),
	caption.above=TRUE,label="table:models1transition"
	)
options(digits=7)
AIC(dj1T)
AIC(dj1.absT)
AIC(df1T)
AIC(df1.absT)
options(digits=2)

dj2T <- (glm(djdj_changeany2 ~ CWonset3years + transition +	
		coup3yrs,family=binomial(link="logit"),
		data= dj.democ.data2))			
df2T <- (glm(sigchange ~ CWonset3years + transition +	
		coup3yrs,family=binomial(link="logit"),
		data= df.democ.data2))

#
# Appendix Table 9, including transitions, below:
#
screenreg(list(coeftest(dj2T, vcov = vcovHC(dj2T, "HC1")), 
	coeftest(df2T, vcov = vcovHC(df2T, "HC1"))), 
	stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE,
	custom.coef.names=c(
	"(Intercept)",
	"Conflict onset",
	"Autocratic transition",
	"Coup"
	),
	caption.above=TRUE,label="table:models2transition"
	)
options(digits=7)
AIC(dj2T)
AIC(df2T)
options(digits=2)

# Standardize the coefficient for conflict years:
dj.democ.data2$conflictyears <- as.numeric(as.character(dj.democ.data2$conflictyears))
dj.democ.data2$conflictyears.std <- (dj.democ.data2$conflictyears - 
	mean(dj.democ.data2$conflictyears,na.rm=TRUE))/
	(2*sd(dj.democ.data2$conflictyears,na.rm=TRUE))
df.democ.data2$conflictyears.std <- (df.democ.data2$conflictyears - 
	mean(df.democ.data2$conflictyears,na.rm=TRUE))/
	(2*sd(df.democ.data2$conflictyears,na.rm=TRUE))

dj.years1T <- lm(djji_diff ~ CWonset3years + conflictyears.std + 
		transition + coup3yrs, data=dj.democ.data2)
dj.years1.absT <- lm(abs(djji_diff) ~ CWonset3years + conflictyears.std + 
		transition + coup3yrs, data=dj.democ.data2)
dj.years2T <- (glm(djdj_changeany2 ~ CWonset3years +  conflictyears.std + transition +	
		coup3yrs,family=binomial(link="logit"),
		data= dj.democ.data2))				
df.years1T <- lm(difflji3yrs ~ CWonset3years + conflictyears.std + 
		transition + coup3yrs,data= df.democ.data2)
df.years1.absT <- lm(abs(difflji3yrs) ~ CWonset3years + conflictyears.std + 
		transition + coup3yrs, data=df.democ.data2)
df.years2T <- (glm(sigchange ~ CWonset3years + conflictyears.std + transition +	
		coup3yrs,family=binomial(link="logit"),
		data= df.democ.data2))
#
# Code for Appendix Table 10, including transitions, below:
#
screenreg(list(
	coeftest(dj.years1T, vcov = vcovHC(dj.years1T, "HC1")),
	coeftest(dj.years1.absT, vcov = vcovHC(dj.years1.absT, "HC1")),
	coeftest(dj.years2T, vcov = vcovHC(dj.years2T, "HC1")),
	coeftest(df.years1T, vcov = vcovHC(df.years1T, "HC1")),
	coeftest(df.years1.absT, vcov = vcovHC(df.years1.absT, "HC1")),
	coeftest(df.years2T, vcov = vcovHC(df.years2T, "HC1"))
	), 
	stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE,
	custom.coef.names=c(
	"(Intercept)",
	"Conflict onset",
	"Conflict years",
	"Autocratic transition",
	"Coup"
	),
	caption.above=TRUE,label="table:models3transition",sideways=TRUE,
	custom.model.names=c("Model $1_y$","Model $2_y$", "Model $5_y$","Model $3_y$","Model $4_y$", "Model $6_y$")
	)
options(digits=7)
AIC(dj.years1T)
AIC(dj.years1.absT)
AIC(dj.years2T)
AIC(df.years1T)
AIC(df.years1.absT)
AIC(df.years2T)
options(digits=2)
		
#
# Including a secular time trend
#		
# Standardize the coefficient for years:
dj.democ.data$year.std <- (dj.democ.data$year - 
	mean(dj.democ.data$year,na.rm=TRUE))/
	(2*sd(dj.democ.data$year,na.rm=TRUE))
df.democ.data$year.std <- (df.democ.data$year - 
	mean(df.democ.data$year,na.rm=TRUE))/
	(2*sd(df.democ.data$year,na.rm=TRUE))

dj1.years <- (lm(djji_diff ~ CWonset3years + transition +	
		coup3yrs + year.std,
		data= dj.democ.data))
dj1.abs.years <- (lm(abs(djji_diff) ~ CWonset3years + transition +	
		coup3yrs + year.std,
		data= dj.democ.data))
df1.years <- (lm(difflji3yrs ~ CWonset3years + transition +	
		coup3yrs + year.std,
		data= df.democ.data))				
df1.abs.years <- (lm(abs(difflji3yrs) ~ CWonset3years + transition +	
		coup3yrs + year.std,
		data= df.democ.data))				
dj2.years <- (glm(djdj_changeany2 ~ CWonset3years + transition +	
		coup3yrs + year.std,family=binomial(link="logit"),
		data= dj.democ.data))			
df2.years <- (glm(sigchange ~ CWonset3years + transition +	
		coup3yrs + year.std,family=binomial(link="logit"),
		data= df.democ.data))	
#
# Code for Appendix Table 11 for time trend below:
#
texreg(list(dj1.years, dj1.abs.years, df1.years, df1.abs.years,dj2.years, df2.years ), 
	stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE,
	custom.coef.names=c(
	"(Intercept)",
	"Conflict onset",
	"Autocratic interregnum",
	"Coup",
	"Year"
	),
	caption.above=TRUE,label="table:yearmodels1",sideways=FALSE
	)
screenreg(list(coeftest(dj1.years, vcov = vcovHC(dj1.years, "HC1")), 
	coeftest(dj1.abs.years, vcov = vcovHC(dj1.abs.years, "HC1")), 
	coeftest(df1.years, vcov = vcovHC(df1.years, "HC1")), 
	coeftest(df1.abs.years, vcov = vcovHC(df1.abs.years, "HC1")),
	coeftest(dj2.years, vcov = vcovHC(dj2.years, "HC1")),
	coeftest(df2.years, vcov = vcovHC(df2.years, "HC1"))  ), 
	stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE,
	custom.coef.names=c(
	"(Intercept)",
	"Conflict onset",
	"Autocratic interregnum",
	"Coup",
	"Year"
	),
	caption.above=TRUE,label="table:yearmodels1",sideways=FALSE
	)	
options(digits=7)
AIC(dj1.years)
AIC(dj1.abs.years)
AIC(df1.years)
AIC(df1.abs.years)
AIC(dj2.years)
AIC(df2.years)
options(digits=2)


#
# Zero-inflated negative binomial for the absolute de jure data, as
# it is really a count not continuous
#
dj.zi <- zeroinfl(abs(djji_diff) ~ CWonset3years +  
		transition + coup3yrs | 1, dist = "poisson", EM = TRUE,
		data=dj.democ.data)	
dj.years1.zi <- zeroinfl(abs(djji_diff) ~ CWonset3years + conflictyears.std + 
		transition + coup3yrs | 1, dist = "poisson", EM = TRUE,
		data=dj.democ.data)	
dj2.zi <- zeroinfl(djdj_changeany2 ~ CWonset3years +  transition +	
		coup3yrs | 1, dist = "poisson", EM = TRUE,
		data= dj.democ.data)			
#
# Code for Appendix Table 12 below:
#
screenreg(list(dj.zi, dj2.zi, dj.years1.zi), 
	stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE,
	custom.coef.names=c(
	"(Intercept)",
	"Conflict onset",
	"Autocratic interregnum",
	"Coup",
	"(Intercept, zero model)",
	"Conflict years"
		),
	caption.above=TRUE,label="table:zi",
	custom.model.names=c("Model 7", "Model 8","Model 9")
	)


#
# ALTERNATIVE TEMPORAL SPECIFICATIONS
# 
# Figure 3 (time trend) code:

form3 <- lji ~ cname + year + CWonset3years
data3 <- extractdata(form3,data2,na.rm=TRUE)
dim(data3)

m1 <- tapply(data3$lji,data3$year,mean)
m2 <- seq(1961,2009,1)
m3 <- as.data.frame(cbind(m1,m2))

m4 <- unique(data3$cname[data3$CWonset3years ==1])
print(as.character(m4))
data4 <- subset(data3, (cname %in% c("Afghanistan","Algeria","Angola","Argentina", "Azerbaijan", 
	"Bangladesh", "Bolivia", "Bosnia and Herzegovina",
	"Burkina Faso", "Burundi", "Cambodia", "Cameroon", "Central African Republic", "Chad",
	"Chile", "China", "Colombia", "Comoros", "Congo", "Congo, Democratic Republic", "Cote d'Ivoire",
	"Croatia", "Djibouti", "Dominican Republic", "Egypt", "El Salvador", "Eritrea", "Ethiopia (1993-)",
	"France (1963-)", "Georgia", "Ghana", "Guatemala", "Guinea", "Haiti", "India", "Indonesia",
	"Iran", "Iraq", "Israel", "Kenya", "Laos", "Lebanon", "Liberia", "Libya", "Macedonia",
	"Madagascar", "Malaysia (1966-)", "Mali", "Mauritania", "Mauritius", "Mexico", "Moldova",
	"Morocco", "Mozambique", "Myanmar", "Nicaragua", "Niger", "Nigeria", "Pakistan (1971-)", "Panama",
	"Papua New Guinea", "Paraguay", "Peru", "Philippines", "Romania", "Russia", "Rwanda", "Saudi Arabia",
	"Senegal", "Sierra Leone", "Somalia", "South Africa", "Spain", "Sri Lanka", "Sudan (-2011)",
	"Suriname", "Syria", "Tajikistan", "Thailand", "Togo", "Trinidad and Tobago", "Tunisia",
	"Turkey", "Uganda", "Uruguay", "Uzbekistan", "Venezuela", "Vietnam", "Yemen, South",
	"Yugoslavia", "Zimbabwe")))
	
n1 <- tapply(data4$lji,data4$year,mean)
n2 <- seq(1961,2009,1)
n3 <- as.data.frame(cbind(n1,n2))

g1 <- ggplot(m3,aes(x=m2)) + geom_line(y=m1,size=2) + scale_y_continuous('Global mean of latent judicial independence',limits=c(0.2,0.8))
g1 <- g1 + scale_x_continuous('Year')
g1 <- g1 + theme(axis.title.y = element_text(size=16,angle=90),
          axis.text.y=element_text(size=16))
g1 <- g1 + theme(axis.title.x = element_text(size=16,vjust=0),
          axis.text.x  = element_text(size=16))
g1 <- g1 + theme_bw()
g1 <- g1 + geom_line(data=n3,aes(y=n1),size=2,color="gray")
g1
#ggsave(g1,file="September_yearlyaverage2.pdf",height=4,width=7,units="in")

#(2/4 year time trends)
#

form.df2 <- difflji2yrs ~ CWonset2yrs + tomilitary2yrs + 
		tocivilian2yrs + tomonarchy2yrs + conflictyears  +
		coup2years + cname + year + democracylag2 + democracy 
form.dj2 <- djji_diff2years ~ CWonset2yrs + tomilitary2yrs + 
		tocivilian2yrs + tomonarchy2yrs + conflictyears  +
		coup2years + cname + year + democracylag2 + democracy

df.data2 <- extractdata(form.df2,data2,na.rm=TRUE)
dj.data2 <- extractdata(form.dj2,data2,na.rm=TRUE)

df.democ.data2years <- subset(df.data2,democracylag2==1) # Robustness, includes those countries that cease to become democracies
df.democ.data2years   <- subset(df.democ.data2years,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum
dj.democ.data2years  <- subset(dj.data2,democracylag2==1) # Robustness, includes those countries that cease to become democracies 
dj.democ.data2years  <- subset(dj.democ.data2years,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum 

dim(df.democ.data2years)
dim(dj.democ.data2years)
df.democ.data2years$transition <- 0
df.democ.data2years$transition[df.democ.data2years$tomilitary2yrs==1] <- 1
df.democ.data2years$transition[df.democ.data2years$tocivilian2yrs==1] <- 1
df.democ.data2years$transition[df.democ.data2years$tomonarchy2yrs==1] <- 1
dj.democ.data2years$transition <- 0
dj.democ.data2years$transition[dj.democ.data2years$tomilitary2yrs==1] <- 1
dj.democ.data2years$transition[dj.democ.data2years$tocivilian2yrs==1] <- 1
dj.democ.data2years$transition[dj.democ.data2years$tomonarchy2yrs==1] <- 1
dj.democ.data2years$djdj_changeany2yrs <- 0
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$djji_diff2years!=0] <- 1
#need to fix by hand three countries where +/- change happens the same year so change is coded as no change (incorrectly)
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="Canada"
	& dj.democ.data2years$year==1999] <- 1
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="Canada"
	& dj.democ.data2years$year==2000] <- dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="Canada"
	& dj.democ.data2years$year==2001] <- dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="Canada"
	& dj.democ.data2years$year==2002] <- dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="Canada"
	& dj.democ.data2years$year==2003] <- 1
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="Armena"
	& dj.democ.data2years$year==2005] <- 1	
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="Armena"
	& dj.democ.data2years$year==2006] <- 1	
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="Armena"
	& dj.democ.data2years$year==2006] <- 1	
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="India"
	& dj.democ.data2years$year==1978] <- 1	
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="India"
	& dj.democ.data2years$year==1979] <- 1	
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="India"
	& dj.democ.data2years$year==1980] <- 1	
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="India"
	& dj.democ.data2years$year==1981] <- 1	
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="India"
	& dj.democ.data2years$year==1982] <- 1	
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="India"
	& dj.democ.data2years$year==1992] <- 1	
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="India"
	& dj.democ.data2years$year==1993] <- 1		
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="India"
	& dj.democ.data2years$year==1994] <- 1	
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="India"
	& dj.democ.data2years$year==2002] <- 1		
dj.democ.data2years$djdj_changeany2yrs[dj.democ.data2years$cname=="India"
	& dj.democ.data2years$year==2003] <- 1		
	
		
sd(abs(df.democ.data2years$difflji2yrs),na.rm=TRUE)
df.democ.data2years$change2 <- NA
df.democ.data2years$change2[abs(df.democ.data2years$difflji2yrs) > sd(abs(df.democ.data2years$difflji2yrs),na.rm=TRUE)] <- 1
df.democ.data2years$change2[abs(df.democ.data2years$difflji2yrs) <= sd(abs(df.democ.data2years$difflji2yrs),na.rm=TRUE)] <- 0
summary(as.factor(df.democ.data2years$change2))
print(cbind(abs(df.democ.data2years$difflji2yrs),df.democ.data2years$change2))
df.democ.data2years$sigchange2yrs <- df.democ.data2years$change2

dj1 <- (lm(djji_diff2years ~ CWonset2yrs +	
		coup2years,
		data= dj.democ.data2years))
dj1.abs <- (lm(abs(djji_diff2years) ~ CWonset2yrs +	
		coup2years,
		data= dj.democ.data2years))
df1 <- (lm(difflji2yrs ~ CWonset2yrs + transition +	
		coup2years,
		data= df.democ.data2years))				
df1.abs <- (lm(abs(difflji2yrs) ~ CWonset2yrs + transition +	
		coup2years,
		data= df.democ.data2years))		

dj2 <- (glm(djdj_changeany2yrs ~ CWonset2yrs + coup2years,	
		family=binomial(link="logit"),
		data= dj.democ.data2years))			
df2 <- (glm(sigchange2yrs ~ CWonset2yrs + transition +	
		coup2years,family=binomial(link="logit"),
		data= df.democ.data2years))
#
# Code for Appendix Table 13 (2 years) below:
#
screenreg(list(
	coeftest(dj1, vcov = vcovHC(dj1, "HC1")),
	coeftest(dj1.abs, vcov = vcovHC(dj1.abs, "HC1")),
	coeftest(dj2, vcov = vcovHC(dj2, "HC1")),
	coeftest(df1, vcov = vcovHC(df1, "HC1")),
	coeftest(df1.abs, vcov = vcovHC(df1.abs, "HC1")),
	coeftest(df2, vcov = vcovHC(df2, "HC1"))
	), 
	stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE,
	custom.coef.names=c(
	"(Intercept)",
	"Conflict onset",
	"Coup",
	"Autocratic interregnum"
	),
	caption.above=TRUE,label="table:models1_2years",
	custom.model.names=c("Model $1_2$","Model $2_2$", "Model $5_2$","Model $3_2$","Model $4_2$", "Model $6_2$")	
	)

options(digits=7)
AIC(dj1)
AIC(dj1.abs)
AIC(dj2)
AIC(df1)
AIC(df1.abs)
AIC(df2)
options(digits=2)		

#
# 4 year period
# 
sd(abs(data2$difflji4yrs),na.rm=TRUE)
data2$change4 <- NA
data2$change4[abs(data2$difflji4yrs) > sd(abs(data2$difflji4yrs),na.rm=TRUE)] <- 1
data2$change4[abs(data2$difflji4yrs) <= sd(abs(data2$difflji4yrs),na.rm=TRUE)] <- 0
summary(as.factor(data2$change4))
print(cbind(abs(data2$difflji4yrs),data2$change4))
data2$sigchange4yrs <- data2$change4

form.df4 <- sigchange4yrs ~ difflji4yrs + CWonset4yrs + tomilitary4yrs + 
		tocivilian4yrs + tomonarchy4yrs + conflictyears  + 
		coup4yrs + cname + year + democracylag4 + democracy 
form.dj4 <- djji_diff4years ~ CWonset4yrs + tomilitary4yrs + 
		tocivilian4yrs + tomonarchy4yrs + conflictyears  +
		coup4yrs + cname + year + democracylag4 + democracy 

df.data4 <- extractdata(form.df4,data2,na.rm=TRUE)
dj.data4 <- extractdata(form.dj4,data2,na.rm=TRUE)

df.democ.data4years <- subset(df.data4,democracylag4==1) # Robustness, includes those countries that cease to become democracies
df.democ.data4years   <- subset(df.democ.data4years,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum
dj.democ.data4years  <- subset(dj.data4,democracylag4==1) # Robustness, includes those countries that cease to become democracies 
dj.democ.data4years  <- subset(dj.democ.data4years,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum 


dim(df.democ.data4years)
dim(dj.democ.data4years)
df.democ.data4years$transition <- 0
df.democ.data4years$transition[df.democ.data4years$tomilitary4yrs==1] <- 1
df.democ.data4years$transition[df.democ.data4years$tocivilian4yrs==1] <- 1
df.democ.data4years$transition[df.democ.data4years$tomonarchy4yrs==1] <- 1
dj.democ.data4years$transition <- 0
dj.democ.data4years$transition[dj.democ.data4years$tomilitary4yrs==1] <- 1
dj.democ.data4years$transition[dj.democ.data4years$tocivilian4yrs==1] <- 1
dj.democ.data4years$transition[dj.democ.data4years$tomonarchy4yrs==1] <- 1
dj.democ.data4years$djdj_changeany4yrs <- 0
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$djji_diff4years!=0] <- 1
# A bit more fixing-by-hand:
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="Canada"
	& dj.democ.data4years$year==1999] <- 1
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="Canada"
	& dj.democ.data4years$year==2000] <- dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="Canada"
	& dj.democ.data4years$year==2001] <- dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="Canada"
	& dj.democ.data4years$year==2002] <- dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="Canada"
	& dj.democ.data4years$year==2003] <- 1
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="Canada"
	& dj.democ.data4years$year==2004] <- 1
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="Canada"
	& dj.democ.data4years$year==2005] <- 1
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="Armena"
	& dj.democ.data4years$year==2005] <- 1	
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="Armena"
	& dj.democ.data4years$year==2006] <- 1	
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="Armena"
	& dj.democ.data4years$year==2007] <- 1	
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="Armena"
	& dj.democ.data4years$year==2008] <- 1	
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==1978] <- 1	
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==1979] <- 1	
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==1980] <- 1	
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==1981] <- 1	
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==1982] <- 1	
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==1983] <- 1
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==1984] <- 1		
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==1992] <- 1	
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==1993] <- 1		
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==1994] <- 1	
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==1995] <- 1
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==1996] <- 1	
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==2002] <- 1		
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==2003] <- 1	
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==2004] <- 1		
dj.democ.data4years$djdj_changeany4yrs[dj.democ.data4years$cname=="India"
	& dj.democ.data4years$year==2005] <- 1		
	
	
	
dj1 <- (lm(djji_diff4years ~ CWonset4yrs +	
		transition +	coup4yrs  ,
		data= dj.democ.data4years))
dj1.abs <- (lm(abs(djji_diff4years) ~ CWonset4yrs +	
		transition +	coup4yrs ,
		data= dj.democ.data4years))
df1 <- (lm(difflji4yrs ~ CWonset4yrs + transition +	
		coup4yrs ,
		data= df.democ.data4years))				
df1.abs <- (lm(abs(difflji4yrs) ~ CWonset4yrs + transition +	
		coup4yrs ,
		data= df.democ.data4years))		

dj2 <- (glm(djdj_changeany4yrs ~ CWonset4yrs + transition +	coup4yrs ,	
		family=binomial(link="logit"),
		data= dj.democ.data4years))			
df2 <- (glm(sigchange4yrs ~ CWonset4yrs + transition +	
		coup4yrs ,family=binomial(link="logit"),
		data= df.democ.data4years))

# Code for Appendix Table 14 (4 years) below:
screenreg(list(
	coeftest(dj1, vcov = vcovHC(dj1, "HC1")),
	coeftest(dj1.abs, vcov = vcovHC(dj1.abs, "HC1")),
	coeftest(dj2, vcov = vcovHC(dj2, "HC1")),
	coeftest(df1, vcov = vcovHC(df1, "HC1")),
	coeftest(df1.abs, vcov = vcovHC(df1.abs, "HC1")),
	coeftest(df2, vcov = vcovHC(df2, "HC1"))
	), 
	stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE,
	custom.coef.names=c(
	"(Intercept)",
	"Conflict onset",
	"Autocratic interregnum",
	"Coup"
	),
	caption.above=TRUE,label="table:models1_4years",
	custom.model.names=c("Model $1_4$","Model $2_4$", "Model $5_4$","Model $3_4$","Model $4_4$", "Model $6_4$")	
	)
options(digits=7)
AIC(dj1)
AIC(dj1.abs)
AIC(dj2)
AIC(df1)
AIC(df1.abs)
AIC(df2)
options(digits=2)		