library(foreign)
library(readstata13)
options(digits=2,scipen=120)
setwd("~/Dropbox/Judicial Independence Since Conflict")
#write.csv(data2,file="~/Desktop/epperly_sievert_data.csv")
data2 <- read.csv("~/Dropbox/Judicial Independence Since Conflict/PRQ replication files/Epperly and Sievert PRQ data.csv")

#xtreg difflji3yrs CWonset3years coup3yrs todemocracy3yrs tocivilian3yrs
#tomonarchy3yrs tomilitary3yrs, vce(robust)

library(memisc)
library(foreign)
library(readstata13)
library(simcf)
library(lme4)
library(ggplot2)
library(MASS)
library(reshape2)
library(extrafont)
library(sandwich)
library(lmtest)
library(pscl)
library(texreg)
library(spduration)

data2$conflictyears <- as.numeric(data2$conflictyears)
data2$transition <- 0
data2$transition[data2$tomilitary3yrs==1] <- 1
data2$transition[data2$tocivilian3yrs==1] <- 1
data2$transition[data2$tomonarchy3yrs==1] <- 1

form.df <- difflji3yrs ~ CWonset3years + tomilitary3yrs + 
		tocivilian3yrs + tomonarchy3yrs + conflictyears + transition +
		coup3yrs + cname + year + difflji3yrs + democracylag3 + democracy
form.dj <- djji_diff ~ djdj_changeany2 + djji_diff_trichotomous + 
		CWonset3years + tomilitary3yrs + 
		tocivilian3yrs + tomonarchy3yrs + conflictyears + transition +
		coup3yrs + cname + year  + democracylag3 + democracy

df.data <- extractdata(form.df,data2,na.rm=TRUE)
dj.data <- extractdata(form.dj,data2,na.rm=TRUE)
dim(df.data)
dim(dj.data)
df.democ.data2 <- subset(df.data,democracylag3==1) # Robustness, includes those countries that cease to become democracies
df.democ.data  <- subset(df.democ.data2,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum
dj.democ.data2 <- subset(dj.data,democracylag3==1) # Robustness, includes those countries that cease to become democracies 
dj.democ.data <- subset(dj.democ.data2,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum 

sd(abs(df.democ.data$difflji3yrs),na.rm=TRUE)
df.democ.data$change3 <- NA
df.democ.data$change3[abs(df.democ.data$difflji3yrs) > sd(abs(df.democ.data$difflji3yrs),na.rm=TRUE)] <- 1
df.democ.data$change3[abs(df.democ.data$difflji3yrs) <= sd(abs(df.democ.data$difflji3yrs),na.rm=TRUE)] <- 0
summary(as.factor(df.democ.data$change3))
#print(cbind(abs(df.democ.data$difflji3yrs),df.democ.data$change3))
df.democ.data$sigchange <- df.democ.data$change3
# This gives us those observations among these data that have a >1 standard deviation
# change in the 3-year difference in LJI

dj1 <- glm(djji_diff ~ CWonset3years + transition +	
		coup3yrs,
		data= dj.democ.data, family="gaussian")
dj1.abs <- glm(abs(djji_diff) ~ CWonset3years + transition +	
		coup3yrs,
		data= dj.democ.data, family="gaussian")
df1 <- glm(difflji3yrs ~ CWonset3years + transition +	
		coup3yrs,
		data= df.democ.data, family="gaussian")	
df1.abs <- glm(abs(difflji3yrs) ~ CWonset3years + transition +	
		coup3yrs,
		data= df.democ.data, family="gaussian")				
#
# TABLE 1 below:
#
ct1 <- coeftest(dj1, vcov = vcovHC(dj1, "HC1"))    
se1 <- ct1[,2]
pval1 <- ct1[,4]
ct2 <- coeftest(dj1.abs, vcov = vcovHC(dj1.abs, "HC1"))  
se2 <- ct2[,2]
pval2 <- ct2[,4]
ct3 <- coeftest(df1, vcov = vcovHC(df1, "HC1"))   
se3 <- ct3[,2]
pval3 <- ct3[,4]
ct4 <- coeftest(df1.abs, vcov = vcovHC(df1.abs, "HC1")) 
se4 <- ct4[,2]
pval4 <- ct4[,4]
screenreg(list(dj1, dj1.abs,  df1, df1.abs), 
	override.se=list(se1,se2,se3,se4),
	override.pvalues=list(pval1, pval2, pval3, pval4),
	stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE,
	custom.coef.names=c(
	"(Intercept)",
	"Conflict onset",
	"Autocratic interregnum",
	"Coup"
	),
	caption.above=TRUE,label="table:models1"
	)



dj2 <- (glm(djdj_changeany2 ~ CWonset3years + transition +	
		coup3yrs,family=binomial(link="logit"),
		data= dj.democ.data))			
df2 <- (glm(sigchange ~ CWonset3years + transition +	
		coup3yrs,family=binomial(link="logit"),
		data= df.democ.data))
#
# TABLE 2 below:
#
ct5 <- coeftest(dj2, vcov = vcovHC(dj2, "HC1"))    
se5 <- ct5[,2]
pval5 <- ct5[,4]
ct6 <- coeftest(df2, vcov = vcovHC(df2, "HC1"))    
se6 <- ct6[,2]
pval6 <- ct6[,4]
screenreg(list(dj2, df2),
	override.se=list(se5, se6), override.pvalues=list(pval5,pval6), 
	stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE,
	custom.model.names=c("Model 5", "Model 6"),
	custom.coef.names=c(
	"(Intercept)",
	"Conflict onset",
	"Autocratic interregnum",
	"Coup"
	),
	caption.above=TRUE,label="table:models2"
	)

	
	
#
# Code to produce Figure 1:
# 
beta <- coef(dj2)
covvar <- vcovHC(dj2, "HC1")
x <- cbind(1,seq(0,1,1),mean(dj.democ.data$transition),mean(dj.democ.data$coup3yrs))
beta.sim <- mvrnorm(10000,beta,covvar) 
xb <- x %*% t(beta.sim)
p <- 1/(1 + exp(-xb))
predicted.prob <- apply(p,1,quantile,probs = c(.025,.5,.975))
dat <- data.frame(x = seq(0,1,1), lower = predicted.prob[1,], 
	middle = predicted.prob[2,], upper = predicted.prob[3,])
dj2prob <- dat

beta <- coef(df2)
covvar <- vcovHC(df2, "HC1")
x <- cbind(1,seq(0,1,1),mean(df.democ.data$transition),mean(df.democ.data$coup3yrs))
beta.sim <- mvrnorm(10000,beta,covvar) 
xb <- x %*% t(beta.sim)
p <- 1/(1 + exp(-xb))
predicted.prob <- apply(p,1,quantile,probs = c(.025,.5,.975))
dat <- data.frame(x = seq(0,1,1), lower = predicted.prob[1,], 
	middle = predicted.prob[2,], upper = predicted.prob[3,])
df2prob <- dat

dat1 <- rbind(dj2prob, df2prob)
dat1$model <- c(1,1,2,2)
dat1$model <- as.factor(dat1$model)
class(dat1$model)


p2 <- ggplot(dat1, aes(x = model))
#p2 <- p2 + scale_y_continuous('',limits=c(0.02,0.06),labels=NULL,breaks=c(0.02,0.03,0.04,0.05,0.06))
p2 <- p2 + scale_x_discrete('',labels=c('Model 5 \n(de jure)','Model 6 \n(de facto)'))
p2 <- p2 + geom_pointrange(x=1,y=dat1[1,3],ymin= dat1[1,2],ymax= dat1[1,4],size=2,color="darkgray",pch=1,fatten=2)
p2 <- p2 + annotate("pointrange",x=dat1[2,5],y=dat1[2,3],ymin= dat1[2,2],ymax= dat1[2,4],size=1)
p2 <- p2 + annotate("pointrange",x=dat1[3,5],y=dat1[3,3],ymin= dat1[3,2],ymax= dat1[3,4],size=2,color="darkgray",pch=1,fatten=2)
p2 <- p2 + annotate("pointrange",x=dat1[4,5],y=dat1[4,3],ymin= dat1[4,2],ymax= dat1[4,4],size=1)
p2
p2 <- p2 + scale_y_continuous(expression(paste("Pr(",Delta," judicial independence)")),limits=c(0,0.5),	
		breaks=c(0,0.1,0.2,0.3,0.4,0.5))

p2 <- p2 + theme_bw()
p2 <- p2 + theme(axis.title.y = element_text(size=14,angle=90),axis.text.y=element_text(size=14))
p2 <- p2 + theme(axis.text.x  = element_text(size=14))
p2
#ggsave("~/Dropbox/Judicial Independence Since Conflict/August_2018probplot.pdf",p2,width=5,height=5)


#
# DIRECTIONALITY OF CHANGE
#

# FEDERALISM

data0 <- read.csv("federalism data.csv")

form.df2 <- difflji3yrs ~ CWonset3years + tomilitary3yrs + 
		tocivilian3yrs + tomonarchy3yrs + conflictyears + transition +
		coup3yrs + cname.x + year.x + difflji3yrs + 
		democracylag3 + democracy + agedem + iaep_ufs2
form.dj2 <- djji_diff ~ CWonset3years + tomilitary3yrs + 
		tocivilian3yrs + tomonarchy3yrs + conflictyears + transition +
		coup3yrs + cname.x + year.x + 
		democracylag3 + democracy + agedem + iaep_ufs2
df.data2 <- extractdata(form.df2,data0,na.rm=TRUE)
df.democ.dataA <- subset(df.data2,democracylag3==1) # Robustness, includes those countries that cease to become democracies
df.democ.dataB  <- subset(df.democ.dataA,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum
dj.data2 <- extractdata(form.dj2,data0,na.rm=TRUE)
dj.democ.dataA <- subset(dj.data2,democracylag3==1) # Robustness, includes those countries that cease to become democracies
dj.democ.dataB  <- subset(dj.democ.dataA,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum
dim(df.democ.dataB)
dim(df.democ.data)
cor(df.democ.dataB$iaep_ufs2, df.democ.dataB$CWonset3years,
	use="pairwise.complete.obs")
# Correlated at -0.03

d1 <- subset(data1, democracy==1)
d2 <- subset(d1, CWonset3years==1)
dim(d2)
d2 <- subset(d2, democracylag3==1)
dim(d2)
 
library(ltm)
 
fed <- subset(d2, iaep_ufs2==1)
cent <- subset(d2, iaep_ufs2==0)
dim(fed)
fed <- subset(fed, difflji3yrs!="NA")
dim(fed)
dim(cent)
cent <- subset(cent, difflji3yrs!="NA")
dim(cent)

length(fed$difflji3yrs[fed$difflji3yrs < -0.01])/length(fed$difflji3yrs)
length(fed$difflji3yrs[fed$difflji3yrs > 0.01])/length(fed$difflji3yrs)
length(fed$difflji3yrs[fed$difflji3yrs < 0.01 & fed$difflji3yrs > -0.01])/length(fed$difflji3yrs)
length(cent$difflji3yrs[cent$difflji3yrs < -0.01])/length(cent$difflji3yrs)
length(cent$difflji3yrs[cent$difflji3yrs > 0.01])/length(cent$difflji3yrs)
length(cent$difflji3yrs[cent$difflji3yrs < 0.01 & cent$difflji3yrs > -0.01])/length(cent$difflji3yrs)
 
ks.test(cent$difflji3yrs, fed$difflji3yrs)
ks.test(d2$difflji3yrs[d2$iaep_ufs2 ==1],d2$difflji3yrs[d2$iaep_ufs2 ==0])
summary(fed$difflji3yrs)
summary(cent$difflji3yrs)
#
# Code for Figure 2, plot (a)
# 
par(mfrow=c(1,1),mar=c(2,2,1,1))
plot(density(fed$difflji3yrs,from=min(fed$difflji3yrs),
	to=max(fed$difflji3yrs),bw=0.01),xlim=c(-0.2,0.31),bty="n",
	main="",axes=F,xlab="",cex.lab=1.5,ylab="",col="gray50",typ="n")
abline(h=0,col="white",lwd=4)
lines(density(fed$difflji3yrs,from=min(fed$difflji3yrs),
	to=max(fed$difflji3yrs),bw=0.01),lwd=3,col="gray50")
lines(density(cent$difflji3yrs,from=min(cent$difflji3yrs),
	to=max(cent$difflji3yrs),bw=0.01),lwd=3,col="black",lty="dashed")
axis(1,cex.axis=1.5)
text(0.01,14,pos=4,label="Federal systems",col="gray50",cex=1.5)
text(0.03,8.5,pos=4,label="Centralized systems",col="black",cex=1.5)

fed2 <- subset(d2, iaep_ufs2==1)
cent2 <- subset(d2, iaep_ufs2==0)
fed2 <- subset(fed2, djji_diff!="NA")
cent2 <- subset(cent2, djji_diff!="NA")
dim(fed2);dim(cent2)
summary(as.factor(cent2$djji_diff))/length(cent2$djji_diff)
summary(as.factor(fed2$djji_diff))/length(fed2$djji_diff)
 
#
# Code for Figure 2, plot (b)
# 
par(mfrow=c(1,1),mar=c(2,5,1,1))
plot(seq(1,8,1),seq(0,1,length.out=8),
	typ="n",bty="n",xlab="",ylab="Percent of observations",
	cex.lab=1.5,cex.axis=1.5,main="",axes=FALSE)
axis(2,cex.axis=1.5,at=c(0, 0.5, 1))
rect(xleft=1, ybottom=0, xright=2, ytop = 0.07547, col="black",border=NA)	
rect(xleft=3, ybottom=0, xright=4, ytop = 0.86792, col="black",border=NA)	
rect(xleft=4, ybottom=0, xright=5, ytop = 0.92308, col="gray50",border=NA)	
rect(xleft=6, ybottom=0, xright=7, ytop = 0.05660, col="black",border=NA)	
rect(xleft=7, ybottom=0, xright=8, ytop = 0.07692, col="gray50",border=NA)	
axis(1,cex.axis=1.5,at=c(1.5, 4, 7),labels=c(-1,0,1))
text(6.5, 0.93,pos=3.5,label="Federal systems",col="gray50",cex=1.5)
text(0.85, 0.91 ,pos=4,label="Centralized",col="black",cex=1.5) 
 

# AGE OF DEMOCRACY

data2 <- read.csv("Epperly and Sievert PRQ data.csv")

form.df <- difflji3yrs ~ CWonset3years + tomilitary3yrs + 
		tocivilian3yrs + tomonarchy3yrs + conflictyears + transition +
		coup3yrs + cname + year + difflji3yrs + democracylag3 + democracy + agedem
form.dj <- djji_diff ~ djdj_changeany2 + djji_diff_trichotomous + 
		CWonset3years + tomilitary3yrs + 
		tocivilian3yrs + tomonarchy3yrs + conflictyears + transition +
		coup3yrs + cname + year  + democracylag3 + democracy + agedem
df.data <- extractdata(form.df,data2,na.rm=TRUE)
dj.data <- extractdata(form.dj,data2,na.rm=TRUE)
dim(df.data)
dim(dj.data)
df.democ.data2 <- subset(df.data,democracylag3==1) # Robustness, includes those countries that cease to become democracies
df.democ.data  <- subset(df.democ.data2,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum
dj.democ.data2 <- subset(dj.data,democracylag3==1) # Robustness, includes those countries that cease to become democracies 
dj.democ.data <- subset(dj.democ.data2,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum 

biserial.cor(as.numeric(as.character(df.democ.data$agedem)), 
	df.democ.data$CWonset3years,use="complete.obs",level=2)
# correlated at -0.11	
cor(as.numeric(as.character(df.democ.data$agedem)), 
	df.democ.data$difflji3yrs,use="pairwise.complete.obs")

d1 <- subset(data2, democracy==1)
d2 <- subset(d1, CWonset3years==1)
dim(d2)
d2 <- subset(d2, democracylag3==1)
dim(d2)

d2$agedem2 <- as.numeric(d2$agedem)
	
cor(d2$difflji3yrs,log(d2$agedem2),use="pairwise.complete.obs")
#
# Code for Figure 3, plot (a)
# 
plot <- ggplot(d2, aes(x=log(agedem2),y= difflji3yrs)) +geom_point(colour="black",size=2.5,fill="gray50",shape=21) + stat_smooth(colour="black",fill="gray",alpha=0.5,size=2,method="lm")
plot <- plot + theme_bw() 
plot <- plot + scale_x_continuous('log(years democratic)')
plot <- plot + scale_y_continuous(expression(paste(Delta," de facto judicial independence")))
plot <- plot + theme(axis.title.y = element_text(size=14,angle=90),axis.text.y=element_text(size=14))
plot <- plot + theme(axis.title.x = element_text(size=14),axis.text.x=element_text(size=14))
plot
#ggsave("~/Dropbox/Judicial Independence Since Conflict/agedemocracy_dfji_plot.pdf",plot,width=5,height=5)
# The jittering means you will get slightly 
# different locations for each point
r1 <- lm(difflji3yrs ~ log(agedem2),data=d2)
screenreg(list(r1))
#
# Code for Figure 3, plot (b)
# 
g1 <- ggplot(d2,aes(x=log(agedem2),y=djji_diff)) + 
	geom_jitter(colour="black",size=2.5,fill="gray50",shape=21,
	width=0.1,height=0.1)
g1 <- g1 + stat_smooth(method="lm",colour="black",fill="gray",alpha=0.5,size=2)
g1 <- g1 + theme_bw()
g1 <- g1 + scale_x_continuous('log(years democratic)')
g1 <- g1 + scale_y_continuous(expression(paste(Delta," de jure judicial independence")))
g1 <- g1 + theme(axis.title.y = element_text(size=14,angle=90),axis.text.y=element_text(size=14))
g1 <- g1 + theme(axis.title.x = element_text(size=14),axis.text.x=element_text(size=14))
g1
#ggsave("~/Dropbox/Judicial Independence Since Conflict/agedemocracy_djji_plot.pdf",g1,width=5,height=5)


# TYPE OF CONFLICT/DISPUTE TYPE

data2 <- read.csv("Epperly and Sievet PRQ data.csv")

data2$incompatibility_lag1 <- panel_lag("incompatibility","cname","year",
	data=data2,lag=1)
data2$incompatibility_lag2 <- panel_lag("incompatibility","cname","year",
	data=data2,lag=2)
data2$incompatibility_3years <- NA
data2$incompatibility_3years[data2$CWonset3years==0] <- 0
data2$incompatibility_3years[data2$CWonset3years==1] <- 0
summary(as.factor(data2$incompatibility_3years))

data2$incompatibility_3years[data2$incompatibility==2] <- 2
data2$incompatibility_3years[data2$incompatibility==1] <- 1
data2$incompatibility_3years[data2$incompatibility_lag1==2] <- 2
data2$incompatibility_3years[data2$incompatibility_lag1==1] <- 1
data2$incompatibility_3years[data2$incompatibility_lag2==2] <- 2
data2$incompatibility_3years[data2$incompatibility_lag2==1] <- 1
summary(as.factor(data2$incompatibility_3years))

form.df2 <- difflji3yrs ~ CWonset3years + tomilitary3yrs + 
		tocivilian3yrs + tomonarchy3yrs + conflictyears + transition +
		coup3yrs + cname + year + difflji3yrs + 
		democracylag3 + democracy + incompatibility_3years
form.dj2 <- djji_diff ~ CWonset3years + tomilitary3yrs + 
		tocivilian3yrs + tomonarchy3yrs + conflictyears + transition +
		coup3yrs + cname + year + 
		democracylag3 + democracy + incompatibility_3years
df.data2 <- extractdata(form.df2,data2,na.rm=TRUE)
df.democ.dataA <- subset(df.data2,democracylag3==1) # Robustness, includes those countries that cease to become democracies
df.democ.dataB  <- subset(df.democ.dataA,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum
dj.data2 <- extractdata(form.dj2,data2,na.rm=TRUE)
dj.democ.dataA <- subset(dj.data2,democracylag3==1) # Robustness, includes those countries that cease to become democracies
dj.democ.dataB  <- subset(dj.democ.dataA,democracy==1) # Main data, only those that transitioned back to democracy after an autocratic interregnum



summary(as.factor(df.democ.data$CWonset3years))
summary(as.factor(df.democ.dataB$CWonset3years))
df.democ.dataB <- subset(df.democ.dataB, CWonset3years==1)
summary(as.factor(df.democ.dataB$incompatibility_3years))
dj.democ.dataB <- subset(dj.democ.dataB, CWonset3years==1)
summary(as.factor(dj.democ.dataB$CWonset3years))
summary(as.factor(dj.democ.dataB$incompatibility_3years))

biserial.cor(df.democ.dataB$difflji3yrs, 
	df.democ.dataB$incompatibility_3years,use="all.obs",level=2)
biserial.cor(dj.democ.dataB$djji_diff, 
	dj.democ.dataB$incompatibility_3years,use="all.obs",level=2)


government <- subset(df.democ.dataB, incompatibility_3years ==2)
territory <- subset(df.democ.dataB, incompatibility_3years ==1)
dim(government)
government <- subset(government, difflji3yrs!="NA")
dim(government)
dim(territory)
territory <- subset(territory, difflji3yrs!="NA")
dim(territory)	

ks.test(government$difflji3yrs,territory$difflji3yrs)	
	
summary(government$difflji3yrs)	
summary(territory$difflji3yrs)	

length(government$difflji3yrs[government$difflji3yrs < -0.01])/length(government$difflji3yrs)
length(government$difflji3yrs[government$difflji3yrs > 0.01])/length(government$difflji3yrs)
length(government$difflji3yrs[government$difflji3yrs < 0.01 & government$difflji3yrs > -0.01])/length(government$difflji3yrs)

length(territory$difflji3yrs[territory$difflji3yrs > 0.01])/length(territory$difflji3yrs)
length(territory$difflji3yrs[territory$difflji3yrs < -0.01])/length(territory$difflji3yrs)
length(territory$difflji3yrs[territory$difflji3yrs < 0.01 & territory$difflji3yrs > -0.01])/length(territory$difflji3yrs)
#
# Code for Figure 4, plot (a)
# 
par(mfrow=c(1,1),mar=c(2,2,1,1))
plot(density(territory$difflji3yrs,from=min(territory$difflji3yrs),
	to=max(territory$difflji3yrs),bw=0.01),xlim=c(-0.2,0.31),bty="n",
	main="",axes=F,xlab="",cex.lab=1.5,ylab="",col="gray50",typ="n")
abline(h=0,col="white",lwd=4)
lines(density(government$difflji3yrs,from=min(government$difflji3yrs),
	to=max(government$difflji3yrs),bw=0.01),lwd=3,col="gray50")
lines(density(territory$difflji3yrs,from=min(territory$difflji3yrs),
	to=max(territory$difflji3yrs),bw=0.01),lwd=3,col="black",lty="dashed")
axis(1,cex.axis=1.5)
text(0.02, 17, pos=4,label="Territorial",col="black",cex=1.5)
text(0.08, 4.5, pos=4,label="Government",col="gray50",cex=1.5)

government <- subset(dj.democ.dataB, incompatibility_3years ==2)
territory <- subset(dj.democ.dataB, incompatibility_3years ==1)
dim(government)
government <- subset(government, djji_diff!="NA")
dim(government)
dim(territory)
territory <- subset(territory, djji_diff!="NA")
dim(territory)	
summary(as.factor(government$djji_diff))/length(government$djji_diff)
summary(as.factor(territory$djji_diff))/length(territory$djji_diff)
#
# Code for Figure 4, plot (b)
# 
par(mfrow=c(1,1),mar=c(2,5,1,1))
plot(seq(1,8,1),seq(0,1,length.out=8),
	typ="n",bty="n",xlab="",ylab="Percent of observations",
	cex.lab=1.5,cex.axis=1.5,main="",axes=FALSE)
axis(2,cex.axis=1.5,at=c(0, 0.5, 1))
rect(xleft=1, ybottom=0, xright=2, ytop=0.10811, col="gray50",border=NA)	
rect(xleft=3, ybottom=0, xright=4, ytop= 0.92308, col="black",border=NA)	
rect(xleft=4, ybottom=0, xright=5, ytop= 0.83784, col="gray50",border=NA)	
rect(xleft=6, ybottom=0, xright=7, ytop= 0.07692, col="black",border=NA)	
rect(xleft=7, ybottom=0, xright=8, ytop= 0.05405, col="gray50",border=NA)	
axis(1,cex.axis=1.5,at=c(1.5, 4, 7), labels=c(-1,0,1))
text(2.25, 0.96, pos=4,label="Territorial",col="black",cex=1.5)
text(4.5, 0.88, pos=4,label="Government",col="gray50",cex=1.5)








